package sgc.portal.com.com.persistence;

import sgc.portal.base.util.EasyHashMap;
import sgc.portal.com.com.model.AuthGrp;
import sgc.portal.com.com.model.AuthUserPrg;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * 프로그램 목록 매퍼  DAO
 *
 * @author KyungHee Jang(khjang@sgc.co.kr)
 * @version 1.0.0
 * @since  2020. 8. 2.
 */


@Mapper
public interface ComAuthUserPrgMngMapper {

    List<EasyHashMap<String, Object>> selectComAuthPrgMngGrp(AuthUserPrg authUserPrg);

    List<EasyHashMap<String, Object>> selectComAuthPrgMngMenu(AuthGrp authGrp);

    List<EasyHashMap<String, Object>> selectComAuthPrgMngUser(AuthUserPrg authUserPrg);

    List<EasyHashMap<String, Object>> selectComAuthPrgMngUserDtl(AuthUserPrg authUserPrg);



    /*
    int insertComAuthGrpMng(AuthGrp authgrps);

    int updateComAuthGrpMng(AuthGrp authgrps);

    int deleteComAuthGrpMng(AuthGrp authgrps);

    List<EasyHashMap<String, Object>> selectComAuthUserMng(AuthUser authusers);

    List<EasyHashMap<String, Object>> selectComAuthUserNoMng(AuthUser authusers);
    */

    void insertComAuthPrgMngUser(AuthUserPrg authUserPrg);

    void updateComAuthPrgMngUser(AuthUserPrg authUserPrg);

    void deleteComAuthPrgMngUser(AuthUserPrg authUserPrg);


    void insertComAuthPrgMngUserDtl(AuthUserPrg authUserPrg);

    void updateComAuthPrgMngUserDtl(AuthUserPrg authUserPrg);

    void deleteComAuthPrgMngUserDtl(AuthUserPrg authUserPrg);

}

